@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2010 Sourcefire, Inc.
+** Copyright (C) 2010-2013 Sourcefire, Inc.
 ** Author: Michael R. Altizer <maltizer@sourcefire.com>
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -15,7 +15,7 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 #ifdef HAVE_CONFIG_H
@@ -726,7 +726,7 @@ static const DAQ_Verdict verdict_translation_table[MAX_DAQ_VERDICT] = {
     DAQ_VERDICT_PASS        /* DAQ_VERDICT_IGNORE */
 };
 
-static int afpacket_daq_acquire(void *handle, int cnt, DAQ_Analysis_Func_t callback, void *user)
+static int afpacket_daq_acquire(void *handle, int cnt, DAQ_Analysis_Func_t callback, DAQ_Meta_Func_t metaback, void *user)
 {
     AFPacket_Context_t *afpc = (AFPacket_Context_t *) handle;
     AFPacketInstance *instance;
@@ -799,8 +799,12 @@ static int afpacket_daq_acquire(void *handle, int cnt, DAQ_Analysis_Func_t callb
                 daqhdr.pktlen = tp_len;
                 daqhdr.ts.tv_sec = tp_sec;
                 daqhdr.ts.tv_usec = tp_usec;
-                daqhdr.device_index = instance->index;
+                daqhdr.ingress_index = instance->index;
+                daqhdr.egress_index = -1;
+                daqhdr.ingress_group = -1;
+                daqhdr.egress_group = -1;
                 daqhdr.flags = 0;
+                daqhdr.address_space_id = 0;
 
                 if (callback)
                 {
@@ -868,7 +872,7 @@ static int afpacket_daq_inject(void *handle, const DAQ_PktHdr_t *hdr, const uint
     /* Find the instance that the packet was received on. */
     for (instance = afpc->instances; instance; instance = instance->next)
     {
-        if (instance->index == hdr->device_index)
+        if (instance->index == hdr->ingress_index)
             break;
     }
 
@@ -1015,5 +1019,9 @@ const DAQ_Module_t afpacket_daq_module_data =
     .get_datalink_type = afpacket_daq_get_datalink_type,
     .get_errbuf = afpacket_daq_get_errbuf,
     .set_errbuf = afpacket_daq_set_errbuf,
-    .get_device_index = afpacket_daq_get_device_index
+    .get_device_index = afpacket_daq_get_device_index,
+    .modify_flow = NULL,
+    .hup_prep = NULL,
+    .hup_apply = NULL,
+    .hup_post = NULL,
 };
